//   Copyright Naoki Shibata and contributors 2010 - 2025.
// Distributed under the Boost Software License, Version 1.0.
//    (See accompanying file LICENSE.txt or copy at
//          http://www.boost.org/LICENSE_1_0.txt)

#include <stdint.h>
#include <assert.h>
#include <signal.h>
#include <setjmp.h>

#include "misc.h"

#define SLEEF_IMPORT_IS_EXPORT
#include "sleef.h"

#include "dispatcher.h"

NOEXPORT double sleef_cpuid_SCALFMA;
static void tryFMA() { sleef_cpuid_SCALFMA = Sleef_sind1_u10purecfma(sleef_cpuid_SCALFMA); }

#define SUBST_IF_EXT1(funcExt1) if (cpuSupportsExt(tryFMA)) p = funcExt1;
#define SUBST_IF_EXT2(funcExt2)

//

DISPATCH_vf_vf(double, 1, Sleef_sin_u35, Sleef_sind1_u35, Sleef_sind1_u35, pnt_sind1_u35, disp_sind1_u35, Sleef_sind1_u35purec, Sleef_sind1_u35purecfma, Sleef_sind1_u35x)
DISPATCH_vf_vf(float, 1, Sleef_sinf_u35, Sleef_sinf1_u35, Sleef_sinf1_u35, pnt_sinf1_u35, disp_sinf1_u35, Sleef_sinf1_u35purec, Sleef_sinf1_u35purecfma, Sleef_sinf1_u35x)
DISPATCH_vf_vf(double, 1, Sleef_cos_u35, Sleef_cosd1_u35, Sleef_cosd1_u35, pnt_cosd1_u35, disp_cosd1_u35, Sleef_cosd1_u35purec, Sleef_cosd1_u35purecfma, Sleef_cosd1_u35x)
DISPATCH_vf_vf(float, 1, Sleef_cosf_u35, Sleef_cosf1_u35, Sleef_cosf1_u35, pnt_cosf1_u35, disp_cosf1_u35, Sleef_cosf1_u35purec, Sleef_cosf1_u35purecfma, Sleef_cosf1_u35x)
DISPATCH_vf2_vf(double, Sleef_double_2, 1, Sleef_sincos_u35, Sleef_sincosd1_u35, Sleef_sincosd1_u35, pnt_sincosd1_u35, disp_sincosd1_u35, Sleef_sincosd1_u35purec, Sleef_sincosd1_u35purecfma, Sleef_sincosd1_u35x)
DISPATCH_vf2_vf(float, Sleef_float_2, 1, Sleef_sincosf_u35, Sleef_sincosf1_u35, Sleef_sincosf1_u35, pnt_sincosf1_u35, disp_sincosf1_u35, Sleef_sincosf1_u35purec, Sleef_sincosf1_u35purecfma, Sleef_sincosf1_u35x)
DISPATCH_vf_vf(double, 1, Sleef_tan_u35, Sleef_tand1_u35, Sleef_tand1_u35, pnt_tand1_u35, disp_tand1_u35, Sleef_tand1_u35purec, Sleef_tand1_u35purecfma, Sleef_tand1_u35x)
DISPATCH_vf_vf(float, 1, Sleef_tanf_u35, Sleef_tanf1_u35, Sleef_tanf1_u35, pnt_tanf1_u35, disp_tanf1_u35, Sleef_tanf1_u35purec, Sleef_tanf1_u35purecfma, Sleef_tanf1_u35x)
DISPATCH_vf_vf(double, 1, Sleef_asin_u35, Sleef_asind1_u35, Sleef_asind1_u35, pnt_asind1_u35, disp_asind1_u35, Sleef_asind1_u35purec, Sleef_asind1_u35purecfma, Sleef_asind1_u35x)
DISPATCH_vf_vf(float, 1, Sleef_asinf_u35, Sleef_asinf1_u35, Sleef_asinf1_u35, pnt_asinf1_u35, disp_asinf1_u35, Sleef_asinf1_u35purec, Sleef_asinf1_u35purecfma, Sleef_asinf1_u35x)
DISPATCH_vf_vf(double, 1, Sleef_acos_u35, Sleef_acosd1_u35, Sleef_acosd1_u35, pnt_acosd1_u35, disp_acosd1_u35, Sleef_acosd1_u35purec, Sleef_acosd1_u35purecfma, Sleef_acosd1_u35x)
DISPATCH_vf_vf(float, 1, Sleef_acosf_u35, Sleef_acosf1_u35, Sleef_acosf1_u35, pnt_acosf1_u35, disp_acosf1_u35, Sleef_acosf1_u35purec, Sleef_acosf1_u35purecfma, Sleef_acosf1_u35x)
DISPATCH_vf_vf(double, 1, Sleef_atan_u35, Sleef_atand1_u35, Sleef_atand1_u35, pnt_atand1_u35, disp_atand1_u35, Sleef_atand1_u35purec, Sleef_atand1_u35purecfma, Sleef_atand1_u35x)
DISPATCH_vf_vf(float, 1, Sleef_atanf_u35, Sleef_atanf1_u35, Sleef_atanf1_u35, pnt_atanf1_u35, disp_atanf1_u35, Sleef_atanf1_u35purec, Sleef_atanf1_u35purecfma, Sleef_atanf1_u35x)
DISPATCH_vf_vf_vf(double, 1, Sleef_atan2_u35, Sleef_atan2d1_u35, Sleef_atan2d1_u35, pnt_atan2d1_u35, disp_atan2d1_u35, Sleef_atan2d1_u35purec, Sleef_atan2d1_u35purecfma, Sleef_atan2d1_u35x)
DISPATCH_vf_vf_vf(float, 1, Sleef_atan2f_u35, Sleef_atan2f1_u35, Sleef_atan2f1_u35, pnt_atan2f1_u35, disp_atan2f1_u35, Sleef_atan2f1_u35purec, Sleef_atan2f1_u35purecfma, Sleef_atan2f1_u35x)
DISPATCH_vf_vf(double, 1, Sleef_log_u35, Sleef_logd1_u35, Sleef_logd1_u35, pnt_logd1_u35, disp_logd1_u35, Sleef_logd1_u35purec, Sleef_logd1_u35purecfma, Sleef_logd1_u35x)
DISPATCH_vf_vf(float, 1, Sleef_logf_u35, Sleef_logf1_u35, Sleef_logf1_u35, pnt_logf1_u35, disp_logf1_u35, Sleef_logf1_u35purec, Sleef_logf1_u35purecfma, Sleef_logf1_u35x)
DISPATCH_vf_vf(double, 1, Sleef_cbrt_u35, Sleef_cbrtd1_u35, Sleef_cbrtd1_u35, pnt_cbrtd1_u35, disp_cbrtd1_u35, Sleef_cbrtd1_u35purec, Sleef_cbrtd1_u35purecfma, Sleef_cbrtd1_u35x)
DISPATCH_vf_vf(float, 1, Sleef_cbrtf_u35, Sleef_cbrtf1_u35, Sleef_cbrtf1_u35, pnt_cbrtf1_u35, disp_cbrtf1_u35, Sleef_cbrtf1_u35purec, Sleef_cbrtf1_u35purecfma, Sleef_cbrtf1_u35x)
DISPATCH_vf_vf(double, 1, Sleef_sin_u10, Sleef_sind1_u10, Sleef_sind1_u10, pnt_sind1_u10, disp_sind1_u10, Sleef_sind1_u10purec, Sleef_sind1_u10purecfma, Sleef_sind1_u10x)
DISPATCH_vf_vf(float, 1, Sleef_sinf_u10, Sleef_sinf1_u10, Sleef_sinf1_u10, pnt_sinf1_u10, disp_sinf1_u10, Sleef_sinf1_u10purec, Sleef_sinf1_u10purecfma, Sleef_sinf1_u10x)
DISPATCH_vf_vf(double, 1, Sleef_cos_u10, Sleef_cosd1_u10, Sleef_cosd1_u10, pnt_cosd1_u10, disp_cosd1_u10, Sleef_cosd1_u10purec, Sleef_cosd1_u10purecfma, Sleef_cosd1_u10x)
DISPATCH_vf_vf(float, 1, Sleef_cosf_u10, Sleef_cosf1_u10, Sleef_cosf1_u10, pnt_cosf1_u10, disp_cosf1_u10, Sleef_cosf1_u10purec, Sleef_cosf1_u10purecfma, Sleef_cosf1_u10x)
DISPATCH_vf2_vf(double, Sleef_double_2, 1, Sleef_sincos_u10, Sleef_sincosd1_u10, Sleef_sincosd1_u10, pnt_sincosd1_u10, disp_sincosd1_u10, Sleef_sincosd1_u10purec, Sleef_sincosd1_u10purecfma, Sleef_sincosd1_u10x)
DISPATCH_vf2_vf(float, Sleef_float_2, 1, Sleef_sincosf_u10, Sleef_sincosf1_u10, Sleef_sincosf1_u10, pnt_sincosf1_u10, disp_sincosf1_u10, Sleef_sincosf1_u10purec, Sleef_sincosf1_u10purecfma, Sleef_sincosf1_u10x)
DISPATCH_vf_vf(double, 1, Sleef_tan_u10, Sleef_tand1_u10, Sleef_tand1_u10, pnt_tand1_u10, disp_tand1_u10, Sleef_tand1_u10purec, Sleef_tand1_u10purecfma, Sleef_tand1_u10x)
DISPATCH_vf_vf(float, 1, Sleef_tanf_u10, Sleef_tanf1_u10, Sleef_tanf1_u10, pnt_tanf1_u10, disp_tanf1_u10, Sleef_tanf1_u10purec, Sleef_tanf1_u10purecfma, Sleef_tanf1_u10x)
DISPATCH_vf_vf(double, 1, Sleef_asin_u10, Sleef_asind1_u10, Sleef_asind1_u10, pnt_asind1_u10, disp_asind1_u10, Sleef_asind1_u10purec, Sleef_asind1_u10purecfma, Sleef_asind1_u10x)
DISPATCH_vf_vf(float, 1, Sleef_asinf_u10, Sleef_asinf1_u10, Sleef_asinf1_u10, pnt_asinf1_u10, disp_asinf1_u10, Sleef_asinf1_u10purec, Sleef_asinf1_u10purecfma, Sleef_asinf1_u10x)
DISPATCH_vf_vf(double, 1, Sleef_acos_u10, Sleef_acosd1_u10, Sleef_acosd1_u10, pnt_acosd1_u10, disp_acosd1_u10, Sleef_acosd1_u10purec, Sleef_acosd1_u10purecfma, Sleef_acosd1_u10x)
DISPATCH_vf_vf(float, 1, Sleef_acosf_u10, Sleef_acosf1_u10, Sleef_acosf1_u10, pnt_acosf1_u10, disp_acosf1_u10, Sleef_acosf1_u10purec, Sleef_acosf1_u10purecfma, Sleef_acosf1_u10x)
DISPATCH_vf_vf(double, 1, Sleef_atan_u10, Sleef_atand1_u10, Sleef_atand1_u10, pnt_atand1_u10, disp_atand1_u10, Sleef_atand1_u10purec, Sleef_atand1_u10purecfma, Sleef_atand1_u10x)
DISPATCH_vf_vf(float, 1, Sleef_atanf_u10, Sleef_atanf1_u10, Sleef_atanf1_u10, pnt_atanf1_u10, disp_atanf1_u10, Sleef_atanf1_u10purec, Sleef_atanf1_u10purecfma, Sleef_atanf1_u10x)
DISPATCH_vf_vf_vf(double, 1, Sleef_atan2_u10, Sleef_atan2d1_u10, Sleef_atan2d1_u10, pnt_atan2d1_u10, disp_atan2d1_u10, Sleef_atan2d1_u10purec, Sleef_atan2d1_u10purecfma, Sleef_atan2d1_u10x)
DISPATCH_vf_vf_vf(float, 1, Sleef_atan2f_u10, Sleef_atan2f1_u10, Sleef_atan2f1_u10, pnt_atan2f1_u10, disp_atan2f1_u10, Sleef_atan2f1_u10purec, Sleef_atan2f1_u10purecfma, Sleef_atan2f1_u10x)
DISPATCH_vf_vf(double, 1, Sleef_log_u10, Sleef_logd1_u10, Sleef_logd1_u10, pnt_logd1_u10, disp_logd1_u10, Sleef_logd1_u10purec, Sleef_logd1_u10purecfma, Sleef_logd1_u10x)
DISPATCH_vf_vf(float, 1, Sleef_logf_u10, Sleef_logf1_u10, Sleef_logf1_u10, pnt_logf1_u10, disp_logf1_u10, Sleef_logf1_u10purec, Sleef_logf1_u10purecfma, Sleef_logf1_u10x)
DISPATCH_vf_vf(double, 1, Sleef_cbrt_u10, Sleef_cbrtd1_u10, Sleef_cbrtd1_u10, pnt_cbrtd1_u10, disp_cbrtd1_u10, Sleef_cbrtd1_u10purec, Sleef_cbrtd1_u10purecfma, Sleef_cbrtd1_u10x)
DISPATCH_vf_vf(float, 1, Sleef_cbrtf_u10, Sleef_cbrtf1_u10, Sleef_cbrtf1_u10, pnt_cbrtf1_u10, disp_cbrtf1_u10, Sleef_cbrtf1_u10purec, Sleef_cbrtf1_u10purecfma, Sleef_cbrtf1_u10x)
DISPATCH_vf_vf(double, 1, Sleef_exp_u10, Sleef_expd1_u10, Sleef_expd1_u10, pnt_expd1_u10, disp_expd1_u10, Sleef_expd1_u10purec, Sleef_expd1_u10purecfma, Sleef_expd1_u10x)
DISPATCH_vf_vf(float, 1, Sleef_expf_u10, Sleef_expf1_u10, Sleef_expf1_u10, pnt_expf1_u10, disp_expf1_u10, Sleef_expf1_u10purec, Sleef_expf1_u10purecfma, Sleef_expf1_u10x)
DISPATCH_vf_vf_vf(double, 1, Sleef_pow_u10, Sleef_powd1_u10, Sleef_powd1_u10, pnt_powd1_u10, disp_powd1_u10, Sleef_powd1_u10purec, Sleef_powd1_u10purecfma, Sleef_powd1_u10x)
DISPATCH_vf_vf_vf(float, 1, Sleef_powf_u10, Sleef_powf1_u10, Sleef_powf1_u10, pnt_powf1_u10, disp_powf1_u10, Sleef_powf1_u10purec, Sleef_powf1_u10purecfma, Sleef_powf1_u10x)
DISPATCH_vf_vf(double, 1, Sleef_sinh_u10, Sleef_sinhd1_u10, Sleef_sinhd1_u10, pnt_sinhd1_u10, disp_sinhd1_u10, Sleef_sinhd1_u10purec, Sleef_sinhd1_u10purecfma, Sleef_sinhd1_u10x)
DISPATCH_vf_vf(float, 1, Sleef_sinhf_u10, Sleef_sinhf1_u10, Sleef_sinhf1_u10, pnt_sinhf1_u10, disp_sinhf1_u10, Sleef_sinhf1_u10purec, Sleef_sinhf1_u10purecfma, Sleef_sinhf1_u10x)
DISPATCH_vf_vf(double, 1, Sleef_cosh_u10, Sleef_coshd1_u10, Sleef_coshd1_u10, pnt_coshd1_u10, disp_coshd1_u10, Sleef_coshd1_u10purec, Sleef_coshd1_u10purecfma, Sleef_coshd1_u10x)
DISPATCH_vf_vf(float, 1, Sleef_coshf_u10, Sleef_coshf1_u10, Sleef_coshf1_u10, pnt_coshf1_u10, disp_coshf1_u10, Sleef_coshf1_u10purec, Sleef_coshf1_u10purecfma, Sleef_coshf1_u10x)
DISPATCH_vf_vf(double, 1, Sleef_tanh_u10, Sleef_tanhd1_u10, Sleef_tanhd1_u10, pnt_tanhd1_u10, disp_tanhd1_u10, Sleef_tanhd1_u10purec, Sleef_tanhd1_u10purecfma, Sleef_tanhd1_u10x)
DISPATCH_vf_vf(float, 1, Sleef_tanhf_u10, Sleef_tanhf1_u10, Sleef_tanhf1_u10, pnt_tanhf1_u10, disp_tanhf1_u10, Sleef_tanhf1_u10purec, Sleef_tanhf1_u10purecfma, Sleef_tanhf1_u10x)
DISPATCH_vf_vf(double, 1, Sleef_sinh_u35, Sleef_sinhd1_u35, Sleef_sinhd1_u35, pnt_sinhd1_u35, disp_sinhd1_u35, Sleef_sinhd1_u35purec, Sleef_sinhd1_u35purecfma, Sleef_sinhd1_u35x)
DISPATCH_vf_vf(float, 1, Sleef_sinhf_u35, Sleef_sinhf1_u35, Sleef_sinhf1_u35, pnt_sinhf1_u35, disp_sinhf1_u35, Sleef_sinhf1_u35purec, Sleef_sinhf1_u35purecfma, Sleef_sinhf1_u35x)
DISPATCH_vf_vf(double, 1, Sleef_cosh_u35, Sleef_coshd1_u35, Sleef_coshd1_u35, pnt_coshd1_u35, disp_coshd1_u35, Sleef_coshd1_u35purec, Sleef_coshd1_u35purecfma, Sleef_coshd1_u35x)
DISPATCH_vf_vf(float, 1, Sleef_coshf_u35, Sleef_coshf1_u35, Sleef_coshf1_u35, pnt_coshf1_u35, disp_coshf1_u35, Sleef_coshf1_u35purec, Sleef_coshf1_u35purecfma, Sleef_coshf1_u35x)
DISPATCH_vf_vf(double, 1, Sleef_tanh_u35, Sleef_tanhd1_u35, Sleef_tanhd1_u35, pnt_tanhd1_u35, disp_tanhd1_u35, Sleef_tanhd1_u35purec, Sleef_tanhd1_u35purecfma, Sleef_tanhd1_u35x)
DISPATCH_vf_vf(float, 1, Sleef_tanhf_u35, Sleef_tanhf1_u35, Sleef_tanhf1_u35, pnt_tanhf1_u35, disp_tanhf1_u35, Sleef_tanhf1_u35purec, Sleef_tanhf1_u35purecfma, Sleef_tanhf1_u35x)
DISPATCH_vf_vf(float, 1, Sleef_fastsinf_u3500, Sleef_fastsinf1_u3500, Sleef_fastsinf1_u3500, pnt_fastsinf1_u3500, disp_fastsinf1_u3500, Sleef_fastsinf1_u3500purec, Sleef_fastsinf1_u3500purecfma, Sleef_fastsinf1_u3500x)
DISPATCH_vf_vf(float, 1, Sleef_fastcosf_u3500, Sleef_fastcosf1_u3500, Sleef_fastcosf1_u3500, pnt_fastcosf1_u3500, disp_fastcosf1_u3500, Sleef_fastcosf1_u3500purec, Sleef_fastcosf1_u3500purecfma, Sleef_fastcosf1_u3500x)
DISPATCH_vf_vf_vf(float, 1, Sleef_fastpowf_u3500, Sleef_fastpowf1_u3500, Sleef_fastpowf1_u3500, pnt_fastpowf1_u3500, disp_fastpowf1_u3500, Sleef_fastpowf1_u3500purec, Sleef_fastpowf1_u3500purecfma, Sleef_fastpowf1_u3500x)
DISPATCH_vf_vf(double, 1, Sleef_asinh_u10, Sleef_asinhd1_u10, Sleef_asinhd1_u10, pnt_asinhd1_u10, disp_asinhd1_u10, Sleef_asinhd1_u10purec, Sleef_asinhd1_u10purecfma, Sleef_asinhd1_u10x)
DISPATCH_vf_vf(float, 1, Sleef_asinhf_u10, Sleef_asinhf1_u10, Sleef_asinhf1_u10, pnt_asinhf1_u10, disp_asinhf1_u10, Sleef_asinhf1_u10purec, Sleef_asinhf1_u10purecfma, Sleef_asinhf1_u10x)
DISPATCH_vf_vf(double, 1, Sleef_acosh_u10, Sleef_acoshd1_u10, Sleef_acoshd1_u10, pnt_acoshd1_u10, disp_acoshd1_u10, Sleef_acoshd1_u10purec, Sleef_acoshd1_u10purecfma, Sleef_acoshd1_u10x)
DISPATCH_vf_vf(float, 1, Sleef_acoshf_u10, Sleef_acoshf1_u10, Sleef_acoshf1_u10, pnt_acoshf1_u10, disp_acoshf1_u10, Sleef_acoshf1_u10purec, Sleef_acoshf1_u10purecfma, Sleef_acoshf1_u10x)
DISPATCH_vf_vf(double, 1, Sleef_atanh_u10, Sleef_atanhd1_u10, Sleef_atanhd1_u10, pnt_atanhd1_u10, disp_atanhd1_u10, Sleef_atanhd1_u10purec, Sleef_atanhd1_u10purecfma, Sleef_atanhd1_u10x)
DISPATCH_vf_vf(float, 1, Sleef_atanhf_u10, Sleef_atanhf1_u10, Sleef_atanhf1_u10, pnt_atanhf1_u10, disp_atanhf1_u10, Sleef_atanhf1_u10purec, Sleef_atanhf1_u10purecfma, Sleef_atanhf1_u10x)
DISPATCH_vf_vf(double, 1, Sleef_exp2_u10, Sleef_exp2d1_u10, Sleef_exp2d1_u10, pnt_exp2d1_u10, disp_exp2d1_u10, Sleef_exp2d1_u10purec, Sleef_exp2d1_u10purecfma, Sleef_exp2d1_u10x)
DISPATCH_vf_vf(float, 1, Sleef_exp2f_u10, Sleef_exp2f1_u10, Sleef_exp2f1_u10, pnt_exp2f1_u10, disp_exp2f1_u10, Sleef_exp2f1_u10purec, Sleef_exp2f1_u10purecfma, Sleef_exp2f1_u10x)
DISPATCH_vf_vf(double, 1, Sleef_exp2_u35, Sleef_exp2d1_u35, Sleef_exp2d1_u35, pnt_exp2d1_u35, disp_exp2d1_u35, Sleef_exp2d1_u35purec, Sleef_exp2d1_u35purecfma, Sleef_exp2d1_u35x)
DISPATCH_vf_vf(float, 1, Sleef_exp2f_u35, Sleef_exp2f1_u35, Sleef_exp2f1_u35, pnt_exp2f1_u35, disp_exp2f1_u35, Sleef_exp2f1_u35purec, Sleef_exp2f1_u35purecfma, Sleef_exp2f1_u35x)
DISPATCH_vf_vf(double, 1, Sleef_exp10_u10, Sleef_exp10d1_u10, Sleef_exp10d1_u10, pnt_exp10d1_u10, disp_exp10d1_u10, Sleef_exp10d1_u10purec, Sleef_exp10d1_u10purecfma, Sleef_exp10d1_u10x)
DISPATCH_vf_vf(float, 1, Sleef_exp10f_u10, Sleef_exp10f1_u10, Sleef_exp10f1_u10, pnt_exp10f1_u10, disp_exp10f1_u10, Sleef_exp10f1_u10purec, Sleef_exp10f1_u10purecfma, Sleef_exp10f1_u10x)
DISPATCH_vf_vf(double, 1, Sleef_exp10_u35, Sleef_exp10d1_u35, Sleef_exp10d1_u35, pnt_exp10d1_u35, disp_exp10d1_u35, Sleef_exp10d1_u35purec, Sleef_exp10d1_u35purecfma, Sleef_exp10d1_u35x)
DISPATCH_vf_vf(float, 1, Sleef_exp10f_u35, Sleef_exp10f1_u35, Sleef_exp10f1_u35, pnt_exp10f1_u35, disp_exp10f1_u35, Sleef_exp10f1_u35purec, Sleef_exp10f1_u35purecfma, Sleef_exp10f1_u35x)
DISPATCH_vf_vf(double, 1, Sleef_expm1_u10, Sleef_expm1d1_u10, Sleef_expm1d1_u10, pnt_expm1d1_u10, disp_expm1d1_u10, Sleef_expm1d1_u10purec, Sleef_expm1d1_u10purecfma, Sleef_expm1d1_u10x)
DISPATCH_vf_vf(float, 1, Sleef_expm1f_u10, Sleef_expm1f1_u10, Sleef_expm1f1_u10, pnt_expm1f1_u10, disp_expm1f1_u10, Sleef_expm1f1_u10purec, Sleef_expm1f1_u10purecfma, Sleef_expm1f1_u10x)
DISPATCH_vf_vf(double, 1, Sleef_log10_u10, Sleef_log10d1_u10, Sleef_log10d1_u10, pnt_log10d1_u10, disp_log10d1_u10, Sleef_log10d1_u10purec, Sleef_log10d1_u10purecfma, Sleef_log10d1_u10x)
DISPATCH_vf_vf(float, 1, Sleef_log10f_u10, Sleef_log10f1_u10, Sleef_log10f1_u10, pnt_log10f1_u10, disp_log10f1_u10, Sleef_log10f1_u10purec, Sleef_log10f1_u10purecfma, Sleef_log10f1_u10x)
DISPATCH_vf_vf(double, 1, Sleef_log2_u10, Sleef_log2d1_u10, Sleef_log2d1_u10, pnt_log2d1_u10, disp_log2d1_u10, Sleef_log2d1_u10purec, Sleef_log2d1_u10purecfma, Sleef_log2d1_u10x)
DISPATCH_vf_vf(float, 1, Sleef_log2f_u10, Sleef_log2f1_u10, Sleef_log2f1_u10, pnt_log2f1_u10, disp_log2f1_u10, Sleef_log2f1_u10purec, Sleef_log2f1_u10purecfma, Sleef_log2f1_u10x)
DISPATCH_vf_vf(double, 1, Sleef_log2_u35, Sleef_log2d1_u35, Sleef_log2d1_u35, pnt_log2d1_u35, disp_log2d1_u35, Sleef_log2d1_u35purec, Sleef_log2d1_u35purecfma, Sleef_log2d1_u35x)
DISPATCH_vf_vf(float, 1, Sleef_log2f_u35, Sleef_log2f1_u35, Sleef_log2f1_u35, pnt_log2f1_u35, disp_log2f1_u35, Sleef_log2f1_u35purec, Sleef_log2f1_u35purecfma, Sleef_log2f1_u35x)
DISPATCH_vf_vf(double, 1, Sleef_log1p_u10, Sleef_log1pd1_u10, Sleef_log1pd1_u10, pnt_log1pd1_u10, disp_log1pd1_u10, Sleef_log1pd1_u10purec, Sleef_log1pd1_u10purecfma, Sleef_log1pd1_u10x)
DISPATCH_vf_vf(float, 1, Sleef_log1pf_u10, Sleef_log1pf1_u10, Sleef_log1pf1_u10, pnt_log1pf1_u10, disp_log1pf1_u10, Sleef_log1pf1_u10purec, Sleef_log1pf1_u10purecfma, Sleef_log1pf1_u10x)
DISPATCH_vf2_vf(double, Sleef_double_2, 1, Sleef_sincospi_u05, Sleef_sincospid1_u05, Sleef_sincospid1_u05, pnt_sincospid1_u05, disp_sincospid1_u05, Sleef_sincospid1_u05purec, Sleef_sincospid1_u05purecfma, Sleef_sincospid1_u05x)
DISPATCH_vf2_vf(float, Sleef_float_2, 1, Sleef_sincospif_u05, Sleef_sincospif1_u05, Sleef_sincospif1_u05, pnt_sincospif1_u05, disp_sincospif1_u05, Sleef_sincospif1_u05purec, Sleef_sincospif1_u05purecfma, Sleef_sincospif1_u05x)
DISPATCH_vf2_vf(double, Sleef_double_2, 1, Sleef_sincospi_u35, Sleef_sincospid1_u35, Sleef_sincospid1_u35, pnt_sincospid1_u35, disp_sincospid1_u35, Sleef_sincospid1_u35purec, Sleef_sincospid1_u35purecfma, Sleef_sincospid1_u35x)
DISPATCH_vf2_vf(float, Sleef_float_2, 1, Sleef_sincospif_u35, Sleef_sincospif1_u35, Sleef_sincospif1_u35, pnt_sincospif1_u35, disp_sincospif1_u35, Sleef_sincospif1_u35purec, Sleef_sincospif1_u35purecfma, Sleef_sincospif1_u35x)
DISPATCH_vf_vf(double, 1, Sleef_sinpi_u05, Sleef_sinpid1_u05, Sleef_sinpid1_u05, pnt_sinpid1_u05, disp_sinpid1_u05, Sleef_sinpid1_u05purec, Sleef_sinpid1_u05purecfma, Sleef_sinpid1_u05x)
DISPATCH_vf_vf(float, 1, Sleef_sinpif_u05, Sleef_sinpif1_u05, Sleef_sinpif1_u05, pnt_sinpif1_u05, disp_sinpif1_u05, Sleef_sinpif1_u05purec, Sleef_sinpif1_u05purecfma, Sleef_sinpif1_u05x)
DISPATCH_vf_vf(double, 1, Sleef_cospi_u05, Sleef_cospid1_u05, Sleef_cospid1_u05, pnt_cospid1_u05, disp_cospid1_u05, Sleef_cospid1_u05purec, Sleef_cospid1_u05purecfma, Sleef_cospid1_u05x)
DISPATCH_vf_vf(float, 1, Sleef_cospif_u05, Sleef_cospif1_u05, Sleef_cospif1_u05, pnt_cospif1_u05, disp_cospif1_u05, Sleef_cospif1_u05purec, Sleef_cospif1_u05purecfma, Sleef_cospif1_u05x)
DISPATCH_vf_vf_vi(double, int32_t, 1, Sleef_ldexp, Sleef_ldexpd1, Sleef_ldexpd1, pnt_ldexpd1, disp_ldexpd1, Sleef_ldexpd1_purec, Sleef_ldexpd1_purecfma, Sleef_ldexpd1_x)
DISPATCH_vi_vf(double, int32_t, 1, Sleef_ilogb, Sleef_ilogbd1, Sleef_ilogbd1, pnt_ilogbd1, disp_ilogbd1, Sleef_ilogbd1_purec, Sleef_ilogbd1_purecfma, Sleef_ilogbd1_x)
DISPATCH_vf_vf_vf_vf(double, 1, Sleef_fma, Sleef_fmad1, Sleef_fmad1, pnt_fmad1, disp_fmad1, Sleef_fmad1_purec, Sleef_fmad1_purecfma, Sleef_fmad1_x)
DISPATCH_vf_vf_vf_vf(float, 1, Sleef_fmaf, Sleef_fmaf1, Sleef_fmaf1, pnt_fmaf1, disp_fmaf1, Sleef_fmaf1_purec, Sleef_fmaf1_purecfma, Sleef_fmaf1_x)
DISPATCH_vf_vf(double, 1, Sleef_sqrt, Sleef_sqrtd1, Sleef_sqrtd1, pnt_sqrtd1, disp_sqrtd1, Sleef_sqrtd1_purec, Sleef_sqrtd1_purecfma, Sleef_sqrtd1_x)
DISPATCH_vf_vf(float, 1, Sleef_sqrtf, Sleef_sqrtf1, Sleef_sqrtf1, pnt_sqrtf1, disp_sqrtf1, Sleef_sqrtf1_purec, Sleef_sqrtf1_purecfma, Sleef_sqrtf1_x)
DISPATCH_vf_vf(double, 1, Sleef_sqrt_u05, Sleef_sqrtd1_u05, Sleef_sqrtd1_u05, pnt_sqrtd1_u05, disp_sqrtd1_u05, Sleef_sqrtd1_u05purec, Sleef_sqrtd1_u05purecfma, Sleef_sqrtd1_u05x)
DISPATCH_vf_vf(float, 1, Sleef_sqrtf_u05, Sleef_sqrtf1_u05, Sleef_sqrtf1_u05, pnt_sqrtf1_u05, disp_sqrtf1_u05, Sleef_sqrtf1_u05purec, Sleef_sqrtf1_u05purecfma, Sleef_sqrtf1_u05x)
DISPATCH_vf_vf(double, 1, Sleef_sqrt_u35, Sleef_sqrtd1_u35, Sleef_sqrtd1_u35, pnt_sqrtd1_u35, disp_sqrtd1_u35, Sleef_sqrtd1_u35purec, Sleef_sqrtd1_u35purecfma, Sleef_sqrtd1_u35x)
DISPATCH_vf_vf(float, 1, Sleef_sqrtf_u35, Sleef_sqrtf1_u35, Sleef_sqrtf1_u35, pnt_sqrtf1_u35, disp_sqrtf1_u35, Sleef_sqrtf1_u35purec, Sleef_sqrtf1_u35purecfma, Sleef_sqrtf1_u35x)
DISPATCH_vf_vf_vf(double, 1, Sleef_hypot_u05, Sleef_hypotd1_u05, Sleef_hypotd1_u05, pnt_hypotd1_u05, disp_hypotd1_u05, Sleef_hypotd1_u05purec, Sleef_hypotd1_u05purecfma, Sleef_hypotd1_u05x)
DISPATCH_vf_vf_vf(float, 1, Sleef_hypotf_u05, Sleef_hypotf1_u05, Sleef_hypotf1_u05, pnt_hypotf1_u05, disp_hypotf1_u05, Sleef_hypotf1_u05purec, Sleef_hypotf1_u05purecfma, Sleef_hypotf1_u05x)
DISPATCH_vf_vf_vf(double, 1, Sleef_hypot_u35, Sleef_hypotd1_u35, Sleef_hypotd1_u35, pnt_hypotd1_u35, disp_hypotd1_u35, Sleef_hypotd1_u35purec, Sleef_hypotd1_u35purecfma, Sleef_hypotd1_u35x)
DISPATCH_vf_vf_vf(float, 1, Sleef_hypotf_u35, Sleef_hypotf1_u35, Sleef_hypotf1_u35, pnt_hypotf1_u35, disp_hypotf1_u35, Sleef_hypotf1_u35purec, Sleef_hypotf1_u35purecfma, Sleef_hypotf1_u35x)
DISPATCH_vf_vf(double, 1, Sleef_fabs, Sleef_fabsd1, Sleef_fabsd1, pnt_fabsd1, disp_fabsd1, Sleef_fabsd1_purec, Sleef_fabsd1_purecfma, Sleef_fabsd1_x)
DISPATCH_vf_vf(float, 1, Sleef_fabsf, Sleef_fabsf1, Sleef_fabsf1, pnt_fabsf1, disp_fabsf1, Sleef_fabsf1_purec, Sleef_fabsf1_purecfma, Sleef_fabsf1_x)
DISPATCH_vf_vf_vf(double, 1, Sleef_copysign, Sleef_copysignd1, Sleef_copysignd1, pnt_copysignd1, disp_copysignd1, Sleef_copysignd1_purec, Sleef_copysignd1_purecfma, Sleef_copysignd1_x)
DISPATCH_vf_vf_vf(float, 1, Sleef_copysignf, Sleef_copysignf1, Sleef_copysignf1, pnt_copysignf1, disp_copysignf1, Sleef_copysignf1_purec, Sleef_copysignf1_purecfma, Sleef_copysignf1_x)
DISPATCH_vf_vf_vf(double, 1, Sleef_fmax, Sleef_fmaxd1, Sleef_fmaxd1, pnt_fmaxd1, disp_fmaxd1, Sleef_fmaxd1_purec, Sleef_fmaxd1_purecfma, Sleef_fmaxd1_x)
DISPATCH_vf_vf_vf(float, 1, Sleef_fmaxf, Sleef_fmaxf1, Sleef_fmaxf1, pnt_fmaxf1, disp_fmaxf1, Sleef_fmaxf1_purec, Sleef_fmaxf1_purecfma, Sleef_fmaxf1_x)
DISPATCH_vf_vf_vf(double, 1, Sleef_fmin, Sleef_fmind1, Sleef_fmind1, pnt_fmind1, disp_fmind1, Sleef_fmind1_purec, Sleef_fmind1_purecfma, Sleef_fmind1_x)
DISPATCH_vf_vf_vf(float, 1, Sleef_fminf, Sleef_fminf1, Sleef_fminf1, pnt_fminf1, disp_fminf1, Sleef_fminf1_purec, Sleef_fminf1_purecfma, Sleef_fminf1_x)
DISPATCH_vf_vf_vf(double, 1, Sleef_fdim, Sleef_fdimd1, Sleef_fdimd1, pnt_fdimd1, disp_fdimd1, Sleef_fdimd1_purec, Sleef_fdimd1_purecfma, Sleef_fdimd1_x)
DISPATCH_vf_vf_vf(float, 1, Sleef_fdimf, Sleef_fdimf1, Sleef_fdimf1, pnt_fdimf1, disp_fdimf1, Sleef_fdimf1_purec, Sleef_fdimf1_purecfma, Sleef_fdimf1_x)
DISPATCH_vf_vf(double, 1, Sleef_trunc, Sleef_truncd1, Sleef_truncd1, pnt_truncd1, disp_truncd1, Sleef_truncd1_purec, Sleef_truncd1_purecfma, Sleef_truncd1_x)
DISPATCH_vf_vf(float, 1, Sleef_truncf, Sleef_truncf1, Sleef_truncf1, pnt_truncf1, disp_truncf1, Sleef_truncf1_purec, Sleef_truncf1_purecfma, Sleef_truncf1_x)
DISPATCH_vf_vf(double, 1, Sleef_floor, Sleef_floord1, Sleef_floord1, pnt_floord1, disp_floord1, Sleef_floord1_purec, Sleef_floord1_purecfma, Sleef_floord1_x)
DISPATCH_vf_vf(float, 1, Sleef_floorf, Sleef_floorf1, Sleef_floorf1, pnt_floorf1, disp_floorf1, Sleef_floorf1_purec, Sleef_floorf1_purecfma, Sleef_floorf1_x)
DISPATCH_vf_vf(double, 1, Sleef_ceil, Sleef_ceild1, Sleef_ceild1, pnt_ceild1, disp_ceild1, Sleef_ceild1_purec, Sleef_ceild1_purecfma, Sleef_ceild1_x)
DISPATCH_vf_vf(float, 1, Sleef_ceilf, Sleef_ceilf1, Sleef_ceilf1, pnt_ceilf1, disp_ceilf1, Sleef_ceilf1_purec, Sleef_ceilf1_purecfma, Sleef_ceilf1_x)
DISPATCH_vf_vf(double, 1, Sleef_round, Sleef_roundd1, Sleef_roundd1, pnt_roundd1, disp_roundd1, Sleef_roundd1_purec, Sleef_roundd1_purecfma, Sleef_roundd1_x)
DISPATCH_vf_vf(float, 1, Sleef_roundf, Sleef_roundf1, Sleef_roundf1, pnt_roundf1, disp_roundf1, Sleef_roundf1_purec, Sleef_roundf1_purecfma, Sleef_roundf1_x)
DISPATCH_vf_vf(double, 1, Sleef_rint, Sleef_rintd1, Sleef_rintd1, pnt_rintd1, disp_rintd1, Sleef_rintd1_purec, Sleef_rintd1_purecfma, Sleef_rintd1_x)
DISPATCH_vf_vf(float, 1, Sleef_rintf, Sleef_rintf1, Sleef_rintf1, pnt_rintf1, disp_rintf1, Sleef_rintf1_purec, Sleef_rintf1_purecfma, Sleef_rintf1_x)
DISPATCH_vf_vf_vf(double, 1, Sleef_nextafter, Sleef_nextafterd1, Sleef_nextafterd1, pnt_nextafterd1, disp_nextafterd1, Sleef_nextafterd1_purec, Sleef_nextafterd1_purecfma, Sleef_nextafterd1_x)
DISPATCH_vf_vf_vf(float, 1, Sleef_nextafterf, Sleef_nextafterf1, Sleef_nextafterf1, pnt_nextafterf1, disp_nextafterf1, Sleef_nextafterf1_purec, Sleef_nextafterf1_purecfma, Sleef_nextafterf1_x)
DISPATCH_vf_vf(double, 1, Sleef_frfrexp, Sleef_frfrexpd1, Sleef_frfrexpd1, pnt_frfrexpd1, disp_frfrexpd1, Sleef_frfrexpd1_purec, Sleef_frfrexpd1_purecfma, Sleef_frfrexpd1_x)
DISPATCH_vf_vf(float, 1, Sleef_frfrexpf, Sleef_frfrexpf1, Sleef_frfrexpf1, pnt_frfrexpf1, disp_frfrexpf1, Sleef_frfrexpf1_purec, Sleef_frfrexpf1_purecfma, Sleef_frfrexpf1_x)
DISPATCH_vi_vf(double, int32_t, 1, Sleef_expfrexp, Sleef_expfrexpd1, Sleef_expfrexpd1, pnt_expfrexpd1, disp_expfrexpd1, Sleef_expfrexpd1_purec, Sleef_expfrexpd1_purecfma, Sleef_expfrexpd1_x)
DISPATCH_vf_vf_vf(double, 1, Sleef_fmod, Sleef_fmodd1, Sleef_fmodd1, pnt_fmodd1, disp_fmodd1, Sleef_fmodd1_purec, Sleef_fmodd1_purecfma, Sleef_fmodd1_x)
DISPATCH_vf_vf_vf(float, 1, Sleef_fmodf, Sleef_fmodf1, Sleef_fmodf1, pnt_fmodf1, disp_fmodf1, Sleef_fmodf1_purec, Sleef_fmodf1_purecfma, Sleef_fmodf1_x)
DISPATCH_vf_vf_vf(double, 1, Sleef_remainder, Sleef_remainderd1, Sleef_remainderd1, pnt_remainderd1, disp_remainderd1, Sleef_remainderd1_purec, Sleef_remainderd1_purecfma, Sleef_remainderd1_x)
DISPATCH_vf_vf_vf(float, 1, Sleef_remainderf, Sleef_remainderf1, Sleef_remainderf1, pnt_remainderf1, disp_remainderf1, Sleef_remainderf1_purec, Sleef_remainderf1_purecfma, Sleef_remainderf1_x)
DISPATCH_vf2_vf(double, Sleef_double_2, 1, Sleef_modf, Sleef_modfd1, Sleef_modfd1, pnt_modfd1, disp_modfd1, Sleef_modfd1_purec, Sleef_modfd1_purecfma, Sleef_modfd1_x)
DISPATCH_vf2_vf(float, Sleef_float_2, 1, Sleef_modff, Sleef_modff1, Sleef_modff1, pnt_modff1, disp_modff1, Sleef_modff1_purec, Sleef_modff1_purecfma, Sleef_modff1_x)
DISPATCH_vf_vf(double, 1, Sleef_lgamma_u10, Sleef_lgammad1_u10, Sleef_lgammad1_u10, pnt_lgammad1_u10, disp_lgammad1_u10, Sleef_lgammad1_u10purec, Sleef_lgammad1_u10purecfma, Sleef_lgammad1_u10x)
DISPATCH_vf_vf(float, 1, Sleef_lgammaf_u10, Sleef_lgammaf1_u10, Sleef_lgammaf1_u10, pnt_lgammaf1_u10, disp_lgammaf1_u10, Sleef_lgammaf1_u10purec, Sleef_lgammaf1_u10purecfma, Sleef_lgammaf1_u10x)
DISPATCH_vf_vf(double, 1, Sleef_tgamma_u10, Sleef_tgammad1_u10, Sleef_tgammad1_u10, pnt_tgammad1_u10, disp_tgammad1_u10, Sleef_tgammad1_u10purec, Sleef_tgammad1_u10purecfma, Sleef_tgammad1_u10x)
DISPATCH_vf_vf(float, 1, Sleef_tgammaf_u10, Sleef_tgammaf1_u10, Sleef_tgammaf1_u10, pnt_tgammaf1_u10, disp_tgammaf1_u10, Sleef_tgammaf1_u10purec, Sleef_tgammaf1_u10purecfma, Sleef_tgammaf1_u10x)
DISPATCH_vf_vf(double, 1, Sleef_erf_u10, Sleef_erfd1_u10, Sleef_erfd1_u10, pnt_erfd1_u10, disp_erfd1_u10, Sleef_erfd1_u10purec, Sleef_erfd1_u10purecfma, Sleef_erfd1_u10x)
DISPATCH_vf_vf(float, 1, Sleef_erff_u10, Sleef_erff1_u10, Sleef_erff1_u10, pnt_erff1_u10, disp_erff1_u10, Sleef_erff1_u10purec, Sleef_erff1_u10purecfma, Sleef_erff1_u10x)
DISPATCH_vf_vf(double, 1, Sleef_erfc_u15, Sleef_erfcd1_u15, Sleef_erfcd1_u15, pnt_erfcd1_u15, disp_erfcd1_u15, Sleef_erfcd1_u15purec, Sleef_erfcd1_u15purecfma, Sleef_erfcd1_u15x)
DISPATCH_vf_vf(float, 1, Sleef_erfcf_u15, Sleef_erfcf1_u15, Sleef_erfcf1_u15, pnt_erfcf1_u15, disp_erfcf1_u15, Sleef_erfcf1_u15purec, Sleef_erfcf1_u15purecfma, Sleef_erfcf1_u15x)
DISPATCH_i_i(1, Sleef_getIntf, Sleef_getIntf1, Sleef_getIntf1, pnt_getIntf1, disp_getIntf1, Sleef_getIntf1_purec, Sleef_getIntf1_purecfma, Sleef_getIntf1_x)
DISPATCH_i_i(1, Sleef_getInt, Sleef_getIntd1, Sleef_getIntd1, pnt_getIntd1, disp_getIntd1, Sleef_getIntd1_purec, Sleef_getIntd1_purecfma, Sleef_getIntd1_x)
DISPATCH_p_i(1, Sleef_getPtrf, Sleef_getPtrf1, Sleef_getPtrf1, pnt_getPtrf1, disp_getPtrf1, Sleef_getPtrf1_purec, Sleef_getPtrf1_purecfma, Sleef_getPtrf1_x)
DISPATCH_p_i(1, Sleef_getPtr, Sleef_getPtrd1, Sleef_getPtrd1, pnt_getPtrd1, disp_getPtrd1, Sleef_getPtrd1_purec, Sleef_getPtrd1_purecfma, Sleef_getPtrd1_x)

//

#ifdef ENABLE_ALIAS
#define DALIAS_d_d(DFUNC, SFUNC) EXPORT CONST double DFUNC(double) __attribute__((alias( stringify( SFUNC ) )));
#define DALIAS_d2_d(DFUNC, SFUNC) EXPORT CONST Sleef_double2 DFUNC(double) __attribute__((alias( stringify( SFUNC ) )));
#define DALIAS_i_d(DFUNC, SFUNC) EXPORT CONST int DFUNC(double) __attribute__((alias( stringify( SFUNC ) )));
#define DALIAS_d_d_d(DFUNC, SFUNC) EXPORT CONST double DFUNC(double, double) __attribute__((alias( stringify( SFUNC ) )));
#define DALIAS_d_d_d_d(DFUNC, SFUNC) EXPORT CONST double DFUNC(double, double, double) __attribute__((alias( stringify( SFUNC ) )));
#define DALIAS_d_d_i(DFUNC, SFUNC) EXPORT CONST double DFUNC(double, int) __attribute__((alias( stringify( SFUNC ) )));
#define DALIAS_f_f(DFUNC, SFUNC) EXPORT CONST float DFUNC(float) __attribute__((alias( stringify( SFUNC ) )));
#define DALIAS_f2_f(DFUNC, SFUNC) EXPORT CONST Sleef_float2 DFUNC(float) __attribute__((alias( stringify( SFUNC ) )));
#define DALIAS_i_f(DFUNC, SFUNC) EXPORT CONST int DFUNC(float) __attribute__((alias( stringify( SFUNC ) )));
#define DALIAS_f_f_f(DFUNC, SFUNC) EXPORT CONST float DFUNC(float, float) __attribute__((alias( stringify( SFUNC ) )));
#define DALIAS_f_f_f_f(DFUNC, SFUNC) EXPORT CONST float DFUNC(float, float, float) __attribute__((alias( stringify( SFUNC ) )));
#define DALIAS_f_f_i(DFUNC, SFUNC) EXPORT CONST float DFUNC(float, int) __attribute__((alias( stringify( SFUNC ) )));
#else
#define DALIAS_d_d(DFUNC, SFUNC) EXPORT CONST double DFUNC(double d) { return SFUNC (d); }
#define DALIAS_d2_d(DFUNC, SFUNC) EXPORT CONST Sleef_double2 DFUNC(double d) { return SFUNC (d); }
#define DALIAS_i_d(DFUNC, SFUNC) EXPORT CONST int DFUNC(double d) { return SFUNC (d); }
#define DALIAS_d_d_d(DFUNC, SFUNC) EXPORT CONST double DFUNC(double x, double y) { return SFUNC (x, y); }
#define DALIAS_d_d_d_d(DFUNC, SFUNC) EXPORT CONST double DFUNC(double x, double y, double z) { return SFUNC (x, y, z); }
#define DALIAS_d_d_i(DFUNC, SFUNC) EXPORT CONST double DFUNC(double x, int i) { return SFUNC (x, i); }
#define DALIAS_f_f(DFUNC, SFUNC) EXPORT CONST float DFUNC(float d) { return SFUNC (d); }
#define DALIAS_f2_f(DFUNC, SFUNC) EXPORT CONST Sleef_float2 DFUNC(float d) { return SFUNC (d); }
#define DALIAS_i_f(DFUNC, SFUNC) EXPORT CONST int DFUNC(float d) { return SFUNC (d); }
#define DALIAS_f_f_f(DFUNC, SFUNC) EXPORT CONST float DFUNC(float x, float y) { return SFUNC (x, y); }
#define DALIAS_f_f_f_f(DFUNC, SFUNC) EXPORT CONST float DFUNC(float x, float y, float z) { return SFUNC (x, y, z); }
#define DALIAS_f_f_i(DFUNC, SFUNC) EXPORT CONST float DFUNC(float x, int i) { return SFUNC (x, i); }
#endif

DALIAS_d_d(Sleef_sin_u10, Sleef_sind1_u10)
DALIAS_d_d(Sleef_cos_u10, Sleef_cosd1_u10)
DALIAS_d_d(Sleef_tan_u10, Sleef_tand1_u10)
DALIAS_d_d(Sleef_sin_u35, Sleef_sind1_u35)
DALIAS_d_d(Sleef_cos_u35, Sleef_cosd1_u35)
DALIAS_d_d(Sleef_tan_u35, Sleef_tand1_u35)
DALIAS_d_d(Sleef_asin_u10, Sleef_asind1_u10)
DALIAS_d_d(Sleef_acos_u10, Sleef_acosd1_u10)
DALIAS_d_d(Sleef_atan_u10, Sleef_atand1_u10)
DALIAS_d_d(Sleef_asin_u35, Sleef_asind1_u35)
DALIAS_d_d(Sleef_acos_u35, Sleef_acosd1_u35)
DALIAS_d_d(Sleef_atan_u35, Sleef_atand1_u35)
DALIAS_d_d(Sleef_sinh_u10, Sleef_sinhd1_u10)
DALIAS_d_d(Sleef_cosh_u10, Sleef_coshd1_u10)
DALIAS_d_d(Sleef_tanh_u10, Sleef_tanhd1_u10)
DALIAS_d_d(Sleef_sinh_u35, Sleef_sinhd1_u35)
DALIAS_d_d(Sleef_cosh_u35, Sleef_coshd1_u35)
DALIAS_d_d(Sleef_tanh_u35, Sleef_tanhd1_u35)
DALIAS_d_d(Sleef_asinh_u10, Sleef_asinhd1_u10)
DALIAS_d_d(Sleef_acosh_u10, Sleef_acoshd1_u10)
DALIAS_d_d(Sleef_atanh_u10, Sleef_atanhd1_u10)
DALIAS_d_d(Sleef_log_u10, Sleef_logd1_u10)
DALIAS_d_d(Sleef_log2_u10, Sleef_log2d1_u10)
DALIAS_d_d(Sleef_log10_u10, Sleef_log10d1_u10)
DALIAS_d_d(Sleef_log1p_u10, Sleef_log1pd1_u10)
DALIAS_d_d(Sleef_log_u35, Sleef_logd1_u35)
DALIAS_d_d(Sleef_log2_u35, Sleef_log2d1_u35)
DALIAS_d_d(Sleef_exp_u10, Sleef_expd1_u10)
DALIAS_d_d(Sleef_exp2_u10, Sleef_exp2d1_u10)
DALIAS_d_d(Sleef_exp10_u10, Sleef_exp10d1_u10)
DALIAS_d_d(Sleef_expm1_u10, Sleef_expm1d1_u10)
DALIAS_d_d(Sleef_exp2_u35, Sleef_exp2d1_u35)
DALIAS_d_d(Sleef_exp10_u35, Sleef_exp10d1_u35)
DALIAS_d_d(Sleef_sqrt, Sleef_sqrtd1)
DALIAS_d_d(Sleef_sqrt_u05, Sleef_sqrtd1_u05)
DALIAS_d_d(Sleef_sqrt_u35, Sleef_sqrtd1_u35)
DALIAS_d_d(Sleef_cbrt_u10, Sleef_cbrtd1_u10)
DALIAS_d_d(Sleef_cbrt_u35, Sleef_cbrtd1_u35)
DALIAS_d_d(Sleef_sinpi_u05, Sleef_sinpid1_u05)
DALIAS_d_d(Sleef_cospi_u05, Sleef_cospid1_u05)
DALIAS_d_d(Sleef_fabs, Sleef_fabsd1)
DALIAS_d_d(Sleef_trunc, Sleef_truncd1)
DALIAS_d_d(Sleef_floor, Sleef_floord1)
DALIAS_d_d(Sleef_ceil, Sleef_ceild1)
DALIAS_d_d(Sleef_round, Sleef_roundd1)
DALIAS_d_d(Sleef_rint, Sleef_rintd1)
DALIAS_d_d(Sleef_lgamma_u10, Sleef_lgammad1_u10)
DALIAS_d_d(Sleef_tgamma_u10, Sleef_tgammad1_u10)
DALIAS_d_d(Sleef_erf_u10, Sleef_erfd1_u10)
DALIAS_d_d(Sleef_erfc_u15, Sleef_erfcd1_u15)
DALIAS_d2_d(Sleef_sincospi_u05, Sleef_sincospid1_u05)
DALIAS_d2_d(Sleef_sincospi_u35, Sleef_sincospid1_u35)
DALIAS_d2_d(Sleef_modf, Sleef_modfd1)
DALIAS_d_d_d(Sleef_copysign, Sleef_copysignd1)
DALIAS_d_d_d(Sleef_fmax, Sleef_fmaxd1)
DALIAS_d_d_d(Sleef_fmin, Sleef_fmind1)
DALIAS_d_d_d(Sleef_fdim, Sleef_fdimd1)
DALIAS_d_d_d(Sleef_nextafter, Sleef_nextafterd1)
DALIAS_i_d(Sleef_expfrexp, Sleef_expfrexpd1)
DALIAS_d_d_d_d(Sleef_fma, Sleef_fmad1)
DALIAS_d_d_d(Sleef_hypot_u05, Sleef_hypotd1_u05)
DALIAS_d_d_d(Sleef_hypot_u35, Sleef_hypotd1_u35)
DALIAS_d_d_d(Sleef_fmod, Sleef_fmodd1)
DALIAS_d_d_d(Sleef_remainder, Sleef_remainderd1)
DALIAS_d_d(Sleef_frfrexp, Sleef_frfrexpd1)
DALIAS_d2_d(Sleef_sincos_u35, Sleef_sincosd1_u35)
DALIAS_d2_d(Sleef_sincos_u10, Sleef_sincosd1_u10)
DALIAS_d_d_d(Sleef_atan2_u35, Sleef_atan2d1_u35)
DALIAS_d_d_d(Sleef_atan2_u10, Sleef_atan2d1_u10)
DALIAS_d_d_d(Sleef_pow_u10, Sleef_powd1_u10)
DALIAS_d_d_i(Sleef_ldexp, Sleef_ldexpd1)
DALIAS_i_d(Sleef_ilogb, Sleef_ilogbd1)

DALIAS_f_f(Sleef_sinf_u35, Sleef_sinf1_u35)
DALIAS_f_f(Sleef_cosf_u35, Sleef_cosf1_u35)
DALIAS_f_f(Sleef_tanf_u35, Sleef_tanf1_u35)
DALIAS_f_f(Sleef_asinf_u35, Sleef_asinf1_u35)
DALIAS_f_f(Sleef_acosf_u35, Sleef_acosf1_u35)
DALIAS_f_f(Sleef_atanf_u35, Sleef_atanf1_u35)
DALIAS_f_f(Sleef_logf_u35, Sleef_logf1_u35)
DALIAS_f_f(Sleef_cbrtf_u35, Sleef_cbrtf1_u35)
DALIAS_f_f(Sleef_sinf_u10, Sleef_sinf1_u10)
DALIAS_f_f(Sleef_cosf_u10, Sleef_cosf1_u10)
DALIAS_f_f(Sleef_fastsinf_u3500, Sleef_fastsinf1_u3500)
DALIAS_f_f(Sleef_fastcosf_u3500, Sleef_fastcosf1_u3500)
DALIAS_f_f(Sleef_tanf_u10, Sleef_tanf1_u10)
DALIAS_f_f(Sleef_asinf_u10, Sleef_asinf1_u10)
DALIAS_f_f(Sleef_acosf_u10, Sleef_acosf1_u10)
DALIAS_f_f(Sleef_atanf_u10, Sleef_atanf1_u10)
DALIAS_f_f(Sleef_logf_u10, Sleef_logf1_u10)
DALIAS_f_f(Sleef_cbrtf_u10, Sleef_cbrtf1_u10)
DALIAS_f_f(Sleef_expf_u10, Sleef_expf1_u10)
DALIAS_f_f(Sleef_sinhf_u10, Sleef_sinhf1_u10)
DALIAS_f_f(Sleef_coshf_u10, Sleef_coshf1_u10)
DALIAS_f_f(Sleef_tanhf_u10, Sleef_tanhf1_u10)
DALIAS_f_f(Sleef_sinhf_u35, Sleef_sinhf1_u35)
DALIAS_f_f(Sleef_coshf_u35, Sleef_coshf1_u35)
DALIAS_f_f(Sleef_tanhf_u35, Sleef_tanhf1_u35)
DALIAS_f_f(Sleef_asinhf_u10, Sleef_asinhf1_u10)
DALIAS_f_f(Sleef_acoshf_u10, Sleef_acoshf1_u10)
DALIAS_f_f(Sleef_atanhf_u10, Sleef_atanhf1_u10)
DALIAS_f_f(Sleef_exp2f_u10, Sleef_exp2f1_u10)
DALIAS_f_f(Sleef_exp10f_u10, Sleef_exp10f1_u10)
DALIAS_f_f(Sleef_exp2f_u35, Sleef_exp2f1_u35)
DALIAS_f_f(Sleef_exp10f_u35, Sleef_exp10f1_u35)
DALIAS_f_f(Sleef_expm1f_u10, Sleef_expm1f1_u10)
DALIAS_f_f(Sleef_log10f_u10, Sleef_log10f1_u10)
DALIAS_f_f(Sleef_log2f_u10, Sleef_log2f1_u10)
DALIAS_f_f(Sleef_log2f_u35, Sleef_log2f1_u35)
DALIAS_f_f(Sleef_log1pf_u10, Sleef_log1pf1_u10)
DALIAS_f_f(Sleef_sinpif_u05, Sleef_sinpif1_u05)
DALIAS_f_f(Sleef_cospif_u05, Sleef_cospif1_u05)
DALIAS_f_f(Sleef_sqrtf_u05, Sleef_sqrtf1_u05)
DALIAS_f_f(Sleef_sqrtf_u35, Sleef_sqrtf1_u35)
DALIAS_f_f(Sleef_lgammaf_u10, Sleef_lgammaf1_u10)
DALIAS_f_f(Sleef_tgammaf_u10, Sleef_tgammaf1_u10)
DALIAS_f_f(Sleef_erff_u10, Sleef_erff1_u10)
DALIAS_f_f(Sleef_erfcf_u15, Sleef_erfcf1_u15)
DALIAS_f_f(Sleef_sqrtf, Sleef_sqrtf1)
DALIAS_f_f(Sleef_fabsf, Sleef_fabsf1)
DALIAS_f_f(Sleef_truncf, Sleef_truncf1)
DALIAS_f_f(Sleef_floorf, Sleef_floorf1)
DALIAS_f_f(Sleef_ceilf, Sleef_ceilf1)
DALIAS_f_f(Sleef_roundf, Sleef_roundf1)
DALIAS_f_f(Sleef_rintf, Sleef_rintf1)
DALIAS_f_f(Sleef_frfrexpf, Sleef_frfrexpf1)
DALIAS_f2_f(Sleef_sincospif_u05, Sleef_sincospif1_u05)
DALIAS_f2_f(Sleef_sincospif_u35, Sleef_sincospif1_u35)
DALIAS_f2_f(Sleef_sincosf_u35, Sleef_sincosf1_u35)
DALIAS_f2_f(Sleef_sincosf_u10, Sleef_sincosf1_u10)
DALIAS_f2_f(Sleef_modff, Sleef_modff1)
DALIAS_f_f_f(Sleef_hypotf_u05, Sleef_hypotf1_u05)
DALIAS_f_f_f(Sleef_hypotf_u35, Sleef_hypotf1_u35)
DALIAS_f_f_f(Sleef_atan2f_u35, Sleef_atan2f1_u35)
DALIAS_f_f_f(Sleef_atan2f_u10, Sleef_atan2f1_u10)
DALIAS_f_f_f(Sleef_powf_u10, Sleef_powf1_u10)
DALIAS_f_f_f(Sleef_fastpowf_u3500, Sleef_fastpowf1_u3500)
DALIAS_f_f_f_f(Sleef_fmaf, Sleef_fmaf1)
DALIAS_f_f_f(Sleef_nextafterf, Sleef_nextafterf1)
DALIAS_f_f_f(Sleef_fmodf, Sleef_fmodf1)
DALIAS_f_f_f(Sleef_remainderf, Sleef_remainderf1)
DALIAS_f_f_f(Sleef_copysignf, Sleef_copysignf1)
DALIAS_f_f_f(Sleef_fmaxf, Sleef_fmaxf1)
DALIAS_f_f_f(Sleef_fminf, Sleef_fminf1)
DALIAS_f_f_f(Sleef_fdimf, Sleef_fdimf1)

CONST float Sleef_ldexpf1_purec(float, int);
EXPORT CONST float Sleef_ldexpf(float f, int i) { return Sleef_ldexpf1_purec(f, i); }
CONST int Sleef_ilogbf1_purec(float);
EXPORT CONST int Sleef_ilogbf(float f) { return Sleef_ilogbf1_purec(f); }
CONST int Sleef_expfrexpf1_purec(float);
EXPORT CONST int Sleef_expfrexpf(float f) { return Sleef_expfrexpf1_purec(f); }
