//   Copyright Naoki Shibata and contributors 2010 - 2025.
// Distributed under the Boost Software License, Version 1.0.
//    (See accompanying file LICENSE.txt or copy at
//          http://www.boost.org/LICENSE_1_0.txt)

#include <stdint.h>
#include <assert.h>
#include <signal.h>
#include <setjmp.h>

#include "misc.h"

#define SLEEF_IMPORT_IS_EXPORT
#include "sleefquad.h"

#include "qdispatcher.h"

NOEXPORT Sleef_quad sleef_cpuid_QUADFMA_0;
static void tryFMA() { sleef_cpuid_QUADFMA_0 = Sleef_sinq1_u10purecfma(sleef_cpuid_QUADFMA_0); }

#define SUBST_IF_EXT1(funcExt1) if (cpuSupportsExt(tryFMA)) p = funcExt1;

//

DISPATCH_vq_vq_vq(Sleef_quad, Sleef_addq1_u05, pnt_addq1_u05, disp_addq1_u05, Sleef_addq1_u05purec, Sleef_addq1_u05purecfma)
DISPATCH_vq_vq_vq(Sleef_quad, Sleef_subq1_u05, pnt_subq1_u05, disp_subq1_u05, Sleef_subq1_u05purec, Sleef_subq1_u05purecfma)
DISPATCH_vq_vq_vq(Sleef_quad, Sleef_mulq1_u05, pnt_mulq1_u05, disp_mulq1_u05, Sleef_mulq1_u05purec, Sleef_mulq1_u05purecfma)
DISPATCH_vq_vq_vq(Sleef_quad, Sleef_divq1_u05, pnt_divq1_u05, disp_divq1_u05, Sleef_divq1_u05purec, Sleef_divq1_u05purecfma)
DISPATCH_vq_vq(Sleef_quad, Sleef_negq1, pnt_negq1, disp_negq1, Sleef_negq1_purec, Sleef_negq1_purecfma)
DISPATCH_vq_vq(Sleef_quad, Sleef_sqrtq1_u05, pnt_sqrtq1_u05, disp_sqrtq1_u05, Sleef_sqrtq1_u05purec, Sleef_sqrtq1_u05purecfma)
DISPATCH_vq_vq(Sleef_quad, Sleef_cbrtq1_u10, pnt_cbrtq1_u10, disp_cbrtq1_u10, Sleef_cbrtq1_u10purec, Sleef_cbrtq1_u10purecfma)
DISPATCH_vx_vq_vq(Sleef_quad, int32_t, Sleef_icmpltq1, pnt_icmpltq1, disp_icmpltq1, Sleef_icmpltq1_purec, Sleef_icmpltq1_purecfma)
DISPATCH_vx_vq_vq(Sleef_quad, int32_t, Sleef_icmpleq1, pnt_icmpleq1, disp_icmpleq1, Sleef_icmpleq1_purec, Sleef_icmpleq1_purecfma)
DISPATCH_vx_vq_vq(Sleef_quad, int32_t, Sleef_icmpgtq1, pnt_icmpgtq1, disp_icmpgtq1, Sleef_icmpgtq1_purec, Sleef_icmpgtq1_purecfma)
DISPATCH_vx_vq_vq(Sleef_quad, int32_t, Sleef_icmpgeq1, pnt_icmpgeq1, disp_icmpgeq1, Sleef_icmpgeq1_purec, Sleef_icmpgeq1_purecfma)
DISPATCH_vx_vq_vq(Sleef_quad, int32_t, Sleef_icmpeqq1, pnt_icmpeqq1, disp_icmpeqq1, Sleef_icmpeqq1_purec, Sleef_icmpeqq1_purecfma)
DISPATCH_vx_vq_vq(Sleef_quad, int32_t, Sleef_icmpneq1, pnt_icmpneq1, disp_icmpneq1, Sleef_icmpneq1_purec, Sleef_icmpneq1_purecfma)
DISPATCH_vx_vq_vq(Sleef_quad, int32_t, Sleef_icmpq1, pnt_icmpq1, disp_icmpq1, Sleef_icmpq1_purec, Sleef_icmpq1_purecfma)
DISPATCH_vx_vq_vq(Sleef_quad, int32_t, Sleef_iunordq1, pnt_iunordq1, disp_iunordq1, Sleef_iunordq1_purec, Sleef_iunordq1_purecfma)
DISPATCH_vx_vq(Sleef_quad, double, Sleef_cast_to_doubleq1, pnt_cast_to_doubleq1, disp_cast_to_doubleq1, Sleef_cast_to_doubleq1_purec, Sleef_cast_to_doubleq1_purecfma)
DISPATCH_vq_vx(Sleef_quad, double, Sleef_cast_from_doubleq1, pnt_cast_from_doubleq1, disp_cast_from_doubleq1, Sleef_cast_from_doubleq1_purec, Sleef_cast_from_doubleq1_purecfma)
DISPATCH_vx_vq(Sleef_quad, int64_t, Sleef_cast_to_int64q1, pnt_cast_to_int64q1, disp_cast_to_int64q1, Sleef_cast_to_int64q1_purec, Sleef_cast_to_int64q1_purecfma)
DISPATCH_vq_vx(Sleef_quad, int64_t, Sleef_cast_from_int64q1, pnt_cast_from_int64q1, disp_cast_from_int64q1, Sleef_cast_from_int64q1_purec, Sleef_cast_from_int64q1_purecfma)
DISPATCH_vx_vq(Sleef_quad, uint64_t, Sleef_cast_to_uint64q1, pnt_cast_to_uint64q1, disp_cast_to_uint64q1, Sleef_cast_to_uint64q1_purec, Sleef_cast_to_uint64q1_purecfma)
DISPATCH_vq_vx(Sleef_quad, uint64_t, Sleef_cast_from_uint64q1, pnt_cast_from_uint64q1, disp_cast_from_uint64q1, Sleef_cast_from_uint64q1_purec, Sleef_cast_from_uint64q1_purecfma)
DISPATCH_q_vq_vx(Sleef_quad, int, Sleef_getq1, pnt_getq1, disp_getq1, Sleef_getq1_purec, Sleef_getq1_purecfma)
DISPATCH_vq_vq_vi_q(Sleef_quad, int, Sleef_setq1, pnt_setq1, disp_setq1, Sleef_setq1_purec, Sleef_setq1_purecfma)
DISPATCH_vq_vx(Sleef_quad, Sleef_quad, Sleef_splatq1, pnt_splatq1, disp_splatq1, Sleef_splatq1_purec, Sleef_splatq1_purecfma)
DISPATCH_vq_vq(Sleef_quad, Sleef_sinq1_u10, pnt_sinq1_u10, disp_sinq1_u10, Sleef_sinq1_u10purec, Sleef_sinq1_u10purecfma)
DISPATCH_vq_vq(Sleef_quad, Sleef_cosq1_u10, pnt_cosq1_u10, disp_cosq1_u10, Sleef_cosq1_u10purec, Sleef_cosq1_u10purecfma)
DISPATCH_vq_vq(Sleef_quad, Sleef_tanq1_u10, pnt_tanq1_u10, disp_tanq1_u10, Sleef_tanq1_u10purec, Sleef_tanq1_u10purecfma)
DISPATCH_vq_vq(Sleef_quad, Sleef_asinq1_u10, pnt_asinq1_u10, disp_asinq1_u10, Sleef_asinq1_u10purec, Sleef_asinq1_u10purecfma)
DISPATCH_vq_vq(Sleef_quad, Sleef_acosq1_u10, pnt_acosq1_u10, disp_acosq1_u10, Sleef_acosq1_u10purec, Sleef_acosq1_u10purecfma)
DISPATCH_vq_vq(Sleef_quad, Sleef_atanq1_u10, pnt_atanq1_u10, disp_atanq1_u10, Sleef_atanq1_u10purec, Sleef_atanq1_u10purecfma)
DISPATCH_vq_vq_vq(Sleef_quad, Sleef_atan2q1_u10, pnt_atan2q1_u10, disp_atan2q1_u10, Sleef_atan2q1_u10purec, Sleef_atan2q1_u10purecfma)
DISPATCH_vq_vq(Sleef_quad, Sleef_expq1_u10, pnt_expq1_u10, disp_expq1_u10, Sleef_expq1_u10purec, Sleef_expq1_u10purecfma)
DISPATCH_vq_vq(Sleef_quad, Sleef_exp2q1_u10, pnt_exp2q1_u10, disp_exp2q1_u10, Sleef_exp2q1_u10purec, Sleef_exp2q1_u10purecfma)
DISPATCH_vq_vq(Sleef_quad, Sleef_exp10q1_u10, pnt_exp10q1_u10, disp_exp10q1_u10, Sleef_exp10q1_u10purec, Sleef_exp10q1_u10purecfma)
DISPATCH_vq_vq(Sleef_quad, Sleef_expm1q1_u10, pnt_expm1q1_u10, disp_expm1q1_u10, Sleef_expm1q1_u10purec, Sleef_expm1q1_u10purecfma)
DISPATCH_vq_vq(Sleef_quad, Sleef_logq1_u10, pnt_logq1_u10, disp_logq1_u10, Sleef_logq1_u10purec, Sleef_logq1_u10purecfma)
DISPATCH_vq_vq(Sleef_quad, Sleef_log2q1_u10, pnt_log2q1_u10, disp_log2q1_u10, Sleef_log2q1_u10purec, Sleef_log2q1_u10purecfma)
DISPATCH_vq_vq(Sleef_quad, Sleef_log10q1_u10, pnt_log10q1_u10, disp_log10q1_u10, Sleef_log10q1_u10purec, Sleef_log10q1_u10purecfma)
DISPATCH_vq_vq(Sleef_quad, Sleef_log1pq1_u10, pnt_log1pq1_u10, disp_log1pq1_u10, Sleef_log1pq1_u10purec, Sleef_log1pq1_u10purecfma)
DISPATCH_vq_vq_vq(Sleef_quad, Sleef_powq1_u10, pnt_powq1_u10, disp_powq1_u10, Sleef_powq1_u10purec, Sleef_powq1_u10purecfma)
DISPATCH_vq_vq(Sleef_quad, Sleef_sinhq1_u10, pnt_sinhq1_u10, disp_sinhq1_u10, Sleef_sinhq1_u10purec, Sleef_sinhq1_u10purecfma)
DISPATCH_vq_vq(Sleef_quad, Sleef_coshq1_u10, pnt_coshq1_u10, disp_coshq1_u10, Sleef_coshq1_u10purec, Sleef_coshq1_u10purecfma)
DISPATCH_vq_vq(Sleef_quad, Sleef_tanhq1_u10, pnt_tanhq1_u10, disp_tanhq1_u10, Sleef_tanhq1_u10purec, Sleef_tanhq1_u10purecfma)
DISPATCH_vq_vq(Sleef_quad, Sleef_asinhq1_u10, pnt_asinhq1_u10, disp_asinhq1_u10, Sleef_asinhq1_u10purec, Sleef_asinhq1_u10purecfma)
DISPATCH_vq_vq(Sleef_quad, Sleef_acoshq1_u10, pnt_acoshq1_u10, disp_acoshq1_u10, Sleef_acoshq1_u10purec, Sleef_acoshq1_u10purecfma)
DISPATCH_vq_vq(Sleef_quad, Sleef_atanhq1_u10, pnt_atanhq1_u10, disp_atanhq1_u10, Sleef_atanhq1_u10purec, Sleef_atanhq1_u10purecfma)
DISPATCH_vq_vq(Sleef_quad, Sleef_truncq1, pnt_truncq1, disp_truncq1, Sleef_truncq1_purec, Sleef_truncq1_purecfma)
DISPATCH_vq_vq(Sleef_quad, Sleef_floorq1, pnt_floorq1, disp_floorq1, Sleef_floorq1_purec, Sleef_floorq1_purecfma)
DISPATCH_vq_vq(Sleef_quad, Sleef_ceilq1, pnt_ceilq1, disp_ceilq1, Sleef_ceilq1_purec, Sleef_ceilq1_purecfma)
DISPATCH_vq_vq(Sleef_quad, Sleef_roundq1, pnt_roundq1, disp_roundq1, Sleef_roundq1_purec, Sleef_roundq1_purecfma)
DISPATCH_vq_vq(Sleef_quad, Sleef_rintq1, pnt_rintq1, disp_rintq1, Sleef_rintq1_purec, Sleef_rintq1_purecfma)
DISPATCH_vq_vq(Sleef_quad, Sleef_fabsq1, pnt_fabsq1, disp_fabsq1, Sleef_fabsq1_purec, Sleef_fabsq1_purecfma)
DISPATCH_vq_vq_vq(Sleef_quad, Sleef_copysignq1, pnt_copysignq1, disp_copysignq1, Sleef_copysignq1_purec, Sleef_copysignq1_purecfma)
DISPATCH_vq_vq_vq(Sleef_quad, Sleef_fmaxq1, pnt_fmaxq1, disp_fmaxq1, Sleef_fmaxq1_purec, Sleef_fmaxq1_purecfma)
DISPATCH_vq_vq_vq(Sleef_quad, Sleef_fminq1, pnt_fminq1, disp_fminq1, Sleef_fminq1_purec, Sleef_fminq1_purecfma)
DISPATCH_vq_vq_vq(Sleef_quad, Sleef_fdimq1_u05, pnt_fdimq1_u05, disp_fdimq1_u05, Sleef_fdimq1_u05purec, Sleef_fdimq1_u05purecfma)
DISPATCH_vq_vq_vq(Sleef_quad, Sleef_fmodq1, pnt_fmodq1, disp_fmodq1, Sleef_fmodq1_purec, Sleef_fmodq1_purecfma)
DISPATCH_vq_vq_vq(Sleef_quad, Sleef_remainderq1, pnt_remainderq1, disp_remainderq1, Sleef_remainderq1_purec, Sleef_remainderq1_purecfma)
DISPATCH_vq_vq_pvx(Sleef_quad, int32_t, Sleef_frexpq1, pnt_frexpq1, disp_frexpq1, Sleef_frexpq1_purec, Sleef_frexpq1_purecfma)
DISPATCH_vq_vq_pvx(Sleef_quad, Sleef_quad, Sleef_modfq1, pnt_modfq1, disp_modfq1, Sleef_modfq1_purec, Sleef_modfq1_purecfma)
DISPATCH_vq_vq_vq(Sleef_quad, Sleef_hypotq1_u05, pnt_hypotq1_u05, disp_hypotq1_u05, Sleef_hypotq1_u05purec, Sleef_hypotq1_u05purecfma)
DISPATCH_vq_vq_vx(Sleef_quad, int32_t, Sleef_ldexpq1, pnt_ldexpq1, disp_ldexpq1, Sleef_ldexpq1_purec, Sleef_ldexpq1_purecfma)
DISPATCH_vx_vq(Sleef_quad, int32_t, Sleef_ilogbq1, pnt_ilogbq1, disp_ilogbq1, Sleef_ilogbq1_purec, Sleef_ilogbq1_purecfma)
DISPATCH_vq_vq_vq_vq(Sleef_quad, Sleef_fmaq1_u05, pnt_fmaq1_u05, disp_fmaq1_u05, Sleef_fmaq1_u05purec, Sleef_fmaq1_u05purecfma)
